/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Avatar.h"
#include "Debug.h"

//___________________________________________
Avatar::Avatar( const ConnectionId& connectionId, QImage avatar ):
    BaseChatCommand( connectionId ),
    avatar_( avatar )
{ Debug::Throw( "Avatar::Avatar.\n" ); }

//__________________________________________________
QDataStream& operator << (QDataStream& stream, const Avatar& avatar )
{
    static const quint32 version = 0;

    stream

        // version
        << version

        // base class members
        << avatar.clientId()
        << avatar.connectionId()
        << avatar.recipients()

        // members
        << avatar.avatar_;

    return stream;
}

//__________________________________________________
QDataStream& operator >> (QDataStream& stream, Avatar& avatar )
{
    quint32 version;
    stream >> version;

    if( version == 0 )
    {

        quint32 clientId;
        ConnectionId connectionId;
        QStringList recipients;
        stream

            // base class members
            >> clientId
            >> connectionId
            >> recipients

            // class members
            >> avatar.avatar_;

        avatar.setClientId( clientId );
        avatar.setConnectionId( connectionId );
        avatar.setRecipients( recipients );

    } else Debug::Throw(0) << "Unrecognized Avatar version: " << version << endl;
    return stream;
}
