/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "AvatarImage.h"

#include "XmlOptions.h"

//__________________________________________________________________
AvatarImage::AvatarImage( QString userName ):
    Counter( "AvatarImage" ),
    userName_( userName )
{
    auto filename( this->filename() );
    if( !filename.isEmpty() && filename.exists() ) load( filename );
}

//__________________________________________________________________
AvatarImage::AvatarImage( QString userName, const QImage& other ):
    QImage( other ),
    Counter( "AvatarImage" ),
    userName_( userName )
{}

//__________________________________________________________________
File AvatarImage::filename( void ) const
{

    if( userName_.isEmpty() ) return File();

    File out = QString( "avatar-%1.png" ).arg( userName_ );
    out = out.addPath( File( XmlOptions::get().raw( "AVATAR_PATH" ) ) );
    return out;
}

//__________________________________________________________________
bool AvatarImage::save( void ) const
{
    if( isNull() || userName_.isEmpty() ) return false;
    else return save( filename() );
}

//__________________________________________________________________
bool AvatarImage::remove( void ) const
{
    if( userName_.isEmpty() ) return false;
    else return filename().remove();
}
