#ifndef AvatarManipulationWidget_h
#define AvatarManipulationWidget_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"

#include <QPixmap>
#include <QPaintEvent>
#include <QWidget>

class AvatarManipulationWidget: public QWidget, public Counter
{

    Q_OBJECT

    public:

    //* constructor
    AvatarManipulationWidget( QWidget* parent, const QPixmap& source );

    //*@name accessors
    //@{

    //* size hint
    virtual QSize sizeHint( void ) const;

    //* minimum size hint
    virtual QSize minimumSizeHint( void ) const
    { return sizeHint(); }

    //* return selected pixmap of a given size
    QPixmap pixmap( int size ) const;

    //@}

    public Q_SLOTS:

    //* reset selection
    void resetSelection( void );

    protected:

    //* paint
    virtual void paintEvent( QPaintEvent* );

    //* resize
    virtual void resizeEvent( QResizeEvent* );

    //* mouse move
    virtual void mousePressEvent( QMouseEvent* );

    //* mouse move
    virtual void mouseMoveEvent( QMouseEvent* );

    //* mouse move
    virtual void mouseReleaseEvent( QMouseEvent* );

    private:

    //* pixmap rect
    void _updateImageRect( void );

    //* drag mode
    enum DragMode
    {
        DragNone,
        DragCenter,
        DragTopLeft,
        DragTopRight,
        DragBottomLeft,
        DragBottomRight
    };

    //* return drag mode from position
    DragMode _dragMode( QPoint ) const;

    //* transform point from image coordinates to widget
    QPointF _toWidgetCoordinates( QPointF ) const;

    //* transform point from widget coordinates to image
    QPointF _toImageCoordinates( QPointF ) const;

    //* original image
    QPixmap source_;

    //* image rect
    QRect imageRect_;

    //* selection
    QPointF dragOffset_;

    //* visible rect
    QRectF selectionRect_;

    DragMode dragMode_ = DragNone;

};

#endif
