#ifndef AvatarSelectionWidget_h
#define AvatarSelectionWidget_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "WeakPointer.h"

#include <QDragEnterEvent>
#include <QDropEvent>
#include <QLabel>
#include <QPixmap>
#include <QPushButton>
#include <QWidget>

class AvatarSelectionWidget: public QLabel, public Counter
{

    Q_OBJECT

    public:

    //* constructor
    AvatarSelectionWidget( QWidget* = nullptr );

    //*@name modifiers
    //@{

    //* set widget value from option value
    void read( void );

    //* set option value from widget value
    void write( ) const;

    //* change avatar button
    QPushButton& changeAvatarButton( QWidget* = nullptr );

    //* unset avatar
    QPushButton& resetAvatarButton( QWidget* = nullptr );

    //@}

    protected:

    //* drag enter event
    virtual void dragEnterEvent( QDragEnterEvent* );

    //* drop event
    virtual void dropEvent( QDropEvent* );

    protected Q_SLOTS:

    //* change picture
    void _changeAvatar( void );

    //* reset
    void _reset( void );

    private:

    //* avatar
    void _setAvatar( const QPixmap& );

    //* update buttons
    void _updateButtons( void );

    //* avatar image
    QPixmap avatar_;

    //* change avatar button
    Base::WeakPointer<QPushButton> changeAvatarButton_;

    //* reset avatar button
    Base::WeakPointer<QPushButton> resetAvatarButton_;

};

#endif
