#ifndef BaseChatCommand_h
#define BaseChatCommand_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ConnectionId.h"
#include "Counter.h"

#include <QStringList>

//_________________________________________
//* command to be send over the server
class BaseChatCommand:public Counter
{

    public:

    //* constructor
    BaseChatCommand( const ConnectionId& connectionId = ConnectionId() ):
        Counter( "BaseChatCommand" ),
        connectionId_( connectionId )
    {}

    //*@name accessors
    //@{

    //* validity
    bool isValid( void ) const
    { return connectionId_.isValid(); }

    //* client id
    quint32 clientId( void ) const
    { return clientId_; }

    //* connection id
    const ConnectionId& connectionId( void ) const
    { return connectionId_; }

    //* list of recipients
    QStringList recipients( void ) const
    { return recipients_; }

    //@}

    //*@name modifiers
    //@{

    //* client id
    void setClientId( quint32 value )
    { clientId_ = value; }

    //* connection id
    void setConnectionId( const ConnectionId& value )
    { connectionId_ = value; }

    //* add recipient
    void addRecipient( const QString& recipient )
    { recipients_.append( recipient ); }

    //* set recipients
    void setRecipients( QStringList recipients )
    { recipients_ = recipients; }

    //@}

    private:

    //* client id
    quint32 clientId_ = 0;

    //* connection id
    ConnectionId connectionId_;

    //* list of recipient user names
    QStringList recipients_;

};

#endif
