/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ChatClient.h"
#include "Debug.h"

#include <QDataStream>
#include <QFile>

static const qint32 CommandType = 1;
static const qint32 FileChunkType = 2;
static const qint32 AvatarType = 3;

//_______________________________________________________
quint32& ChatClient::_counter( void )
{
    static quint32 counter( 0 );
    return counter;
}

//_______________________________________________________
ChatClient::ChatClient( QObject* parent, QTcpSocket* socket ):
    BaseSocketInterface( parent, socket ),
    Counter( "ChatClient" ),
    id_( _counter()++ )
{
    Debug::Throw( "ChatClient::ChatClient.\n" );
    connect( this, SIGNAL(bufferReceived(qint32,QByteArray)), SLOT(_parseBuffer(qint32,QByteArray)) );
}

//_______________________________________________________
void ChatClient::sendAvatar( Avatar avatar )
{
    QByteArray array;
    QDataStream stream( &array, QIODevice::WriteOnly );
    stream << avatar;
    sendBuffer( AvatarType, array );
}

//_______________________________________________________
void ChatClient::sendCommand( ChatCommand command )
{
    QByteArray array;
    QDataStream stream( &array, QIODevice::WriteOnly );
    stream << command;
    sendBuffer( CommandType, array );
}

//_______________________________________________________
void ChatClient::sendFileChunk( FileChunk fileChunk )
{
    // send
    QByteArray array;
    QDataStream stream( &array, QIODevice::WriteOnly );
    stream << fileChunk;
    sendBuffer( FileChunkType, array );

}

//_______________________________________________________
void ChatClient::_parseBuffer( qint32 bufferType, QByteArray buffer )
{
    if( bufferType == AvatarType )
    {

        Avatar avatar;
        QDataStream stream( &buffer, QIODevice::ReadOnly );
        stream >> avatar;
        avatar.setClientId( id_ );
        emit avatarAvailable( avatar );

    } else if( bufferType == CommandType ) {

        ChatCommand command;
        QDataStream stream( &buffer, QIODevice::ReadOnly );
        stream >> command;
        command.setClientId( id_ );
        emit commandAvailable( command );

    } else if( bufferType == FileChunkType ) {

        FileChunk fileChunk;
        QDataStream stream( &buffer, QIODevice::ReadOnly );
        stream >> fileChunk;
        fileChunk.setClientId( id_ );
        emit fileChunkAvailable( fileChunk );

    } else {

        Debug::Throw(0) << "ChatClient::_parseBuffer - unrecognized buffer type: " << bufferType << endl;

    }

}
