#ifndef ChatClient_h
#define ChatClient_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Avatar.h"
#include "BaseSocketInterface.h"
#include "ChatCommand.h"
#include "ConnectionId.h"
#include "Counter.h"
#include "File.h"
#include "FileChunk.h"

#include <QTcpSocket>

//* interprocess communication client
class ChatClient : public BaseSocketInterface, public Counter
{

    //* Qt meta object macro
    Q_OBJECT

    public:

    //* client list
    using List = QList< ChatClient* >;

    //* constructor
    ChatClient( QObject*, QTcpSocket* = nullptr );

    //*@name accessors
    //@{

    //* client id
    quint32 id( void ) const
    { return id_; }

    //* connection id
    ConnectionId connectionId( void ) const
    { return connectionId_; }

    //*@}

    //*@name modifiers
    //@{

    //* connection id
    virtual void setConnectionId( const ConnectionId& value )
    { connectionId_ = value; }

    //@}

    //* used to retrieve client matching id
    class SameIdFTor
    {

        public:

        //* constructor
        SameIdFTor( quint32 id ):
            id_( id )
        {}

        //* predicate
        virtual bool operator() ( const ChatClient* client ) const
        { return client->id() == id_; }

        protected:

        //* prediction
        quint32 id_ = 0;

    };

    public Q_SLOTS:

    //* send avatar over the socket
    void sendAvatar( Avatar );

    //* send chat command over the socket
    void sendCommand( ChatCommand );

    //* send a file over the socket
    void sendFileChunk( FileChunk );

    Q_SIGNALS:

    //* emitted when an avatar is available
    void avatarAvailable( Avatar );

    //* emitted when a message is available
    void commandAvailable( ChatCommand );

    //* emitted when a file is available
    void fileChunkAvailable( FileChunk );

    private Q_SLOTS:

    //* process buffer
    virtual void _parseBuffer( qint32, QByteArray );

    private:

    //* client counter
    static quint32& _counter( void );

    //* client id
    quint32 id_ = 0;

    //* connection id
    ConnectionId connectionId_;

};

#endif
