/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Debug.h"
#include "ChatCommand.h"

//__________________________________________________________________
ChatCommand::CommandMap& ChatCommand::_commandNames( void )
{
    static CommandMap names;
    return names;
}

//_________________________________________
void ChatCommand::_initializeCommandNames( void ) const
{
    if( !_commandNames().empty() ) return;
    _commandNames().insert( None, "" );
    _commandNames().insert( Message, QObject::tr( "Message" ) );

    _commandNames().insert( ConnectionRequest, QObject::tr( "Connection requested" ) );
    _commandNames().insert( ConnectionAccepted, QObject::tr( "Connection accepted" ) );
    _commandNames().insert( ConnectionDenied, QObject::tr( "Connection denied" ) );
    _commandNames().insert( ContactOnline, QObject::tr( "Contact came online" ) );
    _commandNames().insert( ContactOffline, QObject::tr( "Contact went offline" ) );

    _commandNames().insert( FetchMessages, QObject::tr( "Fetch messages from server" ) );
    _commandNames().insert( FetchContacts, QObject::tr( "Fetch contacts" ) );
    _commandNames().insert( Contact, QObject::tr( "Contact (unused)" ) );

    _commandNames().insert( PingServer, QObject::tr( "Ping server" ) );
    _commandNames().insert( PongServer, QObject::tr( "Server pong" ) );

    _commandNames().insert( PingClient, QObject::tr( "Ping client" ) );
    _commandNames().insert( PongClient, QObject::tr( "Client pong" ) );
    _commandNames().insert( ClearContactList, QObject::tr( "Clear list of contacts" ) );
    _commandNames().insert( ClearMessageList, QObject::tr( "Clear local message list" ) );
    _commandNames().insert( UserStateChanged, QObject::tr( "Change user status" ) );
    _commandNames().insert( StartMessageLog, QObject::tr( "Start sending messages" ) );
    _commandNames().insert( StopMessageLog, QObject::tr( "Finished sending messages" ) );
    _commandNames().insert( UserTyping, QObject::tr( "User typing" ) );
    _commandNames().insert( UserNameChanged, QObject::tr( "User name changed" ) );
    _commandNames().insert( FileTransferRequest, QObject::tr( "File transfer requested" ) );
    _commandNames().insert( FileTransferAccepted, QObject::tr( "File transfer accepted" ) );
    _commandNames().insert( FileTransferDenied, QObject::tr( "File transfer denied" ) );
    _commandNames().insert( FileTransferCanceled, QObject::tr( "File transfer cancelled" ) );

}

//___________________________________________
ChatCommand::ChatCommand( const ConnectionId& connectionId, const CommandType& command ):
    BaseChatCommand( connectionId ),
    creationTime_( TimeStamp::now() ),
    command_( command )
{ Debug::Throw( "ChatCommand::ChatCommand.\n" ); }

//__________________________________________________
QDataStream& operator << (QDataStream& stream, const ChatCommand& command )
{
    static const quint32 version = 0;

    stream

        // version
        << version

        // base class members
        << command.clientId()
        << command.connectionId()
        << command.recipients()

        // members
        << command.creationTime_
        << command.receptionTime_
        << quint32(command.command_)
        << command.arguments_
        << command.text_;

    return stream;
}

//__________________________________________________
QDataStream& operator >> (QDataStream& stream, ChatCommand& command )
{
    quint32 version;
    stream >> version;
    if( version == 0 )
    {
        quint32 clientId;
        ConnectionId connectionId;
        QStringList recipients;
        quint32 commandType;
        QStringList arguments;
        stream

            // base class members
            >> clientId
            >> connectionId
            >> recipients

            // class members
            >> command.creationTime_
            >> command.receptionTime_
            >> commandType
            >> arguments
            >> command.text_;

        command.setClientId( clientId );
        command.setConnectionId( connectionId );
        command.setRecipients( recipients );
        command.command_ = (ChatCommand::CommandType) commandType;
        command.arguments_ = CommandLineArguments( arguments );

    } else Debug::Throw(0) << "Unrecognized ChatCommand version: " << version << endl;

    return stream;
}
