#ifndef ChatMessageListDialog_h
#define ChatMessageListDialog_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CustomDialog.h"
#include "ChatMessageModel.h"
#include "ChatMessage.h"
#include "ChatMessageSet.h"
#include "QuestionDialog.h"

#include <QAction>
#include <QBasicTimer>
#include <QLabel>
#include <QPushButton>
#include <QTimerEvent>

class TreeView;

//* handles list of connection attributes
class ChatMessageListDialog: public CustomDialog
{

    Q_OBJECT

    public:

    //* constructor
    ChatMessageListDialog( QWidget* = nullptr, int debugLevel = 1 );

    //* debug level
    void setDebugLevel( int value )
    { debugLevel_ = value; }

    protected Q_SLOTS:

    //* read
    virtual void _reload( void );

    //* edit
    virtual void _edit( void );

    //* remove document classes
    virtual void _remove( void );

    //* remove messages permanently
    virtual void _saveModel( void );

    //* update buttons
    virtual void _updateButtons( void );

    //* update status label
    virtual void _updateStatusLabelDelayed( void );

    virtual void _updateStatusLabel( void );

    protected:

    //* timer event
    virtual void timerEvent( QTimerEvent* );

    //* update title when modified
    void _setModified( bool );

    //* remove messages question dialog
    QuestionDialog* _removeMessagesQuestionDialog( const ChatMessage::List& );

    private:

    //* user treeview
    TreeView* list_ = nullptr;

    //* selection label
    QLabel* statusLabel_ = nullptr;

    //* statusbar update timer
    QBasicTimer statusLabelUpdateTimer_;

    //* model
    ChatMessageModel model_;

    //* list of filenames from message set
    ChatMessageSet::FileSet filenames_;

    //* debug level
    int debugLevel_ = 1;

    //* true if modified
    bool modified_ = false;

    //* edit
    QPushButton* editButton_ = nullptr;

    //* remove button
    QPushButton* removeButton_ = nullptr;

    //* reload button
    QPushButton* reloadButton_ = nullptr;

    //* edit
    QAction* editAction_ = nullptr;

    //* remove action
    QAction* removeAction_ = nullptr;

    //* remove action
    QAction* reloadAction_ = nullptr;

};

#endif
