/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ChatMessageMigration.h"
#include "ResourceMigration.h"

#include "Debug.h"
#include "Util.h"

#include <QDir>

//_________________________________________________________
ChatMessageMigration::ChatMessageMigration( File source ):
    Counter( "ChatMessageMigration" ),
    source_( source )
{ Debug::Throw( "ChatMessageMigration::ChatMessageMigration.\n" ); }

//_________________________________________________________
bool ChatMessageMigration::migrate( File destination ) const
{

    QList<QString> extensions;
    extensions.append( ".new" );

    // generate filename list
    const QStringList filenameCandidates = QDir( source_.path() ).entryList(
        QStringList() << QString( source_.localName() + "-*" ),
        QDir::Hidden|QDir::Files,
        QDir::Name );

    QRegExp dateRegExp( "-(\\d{4,4})-(\\d{2,2})$" );
    for( const auto& filename:filenameCandidates )
    {

        // parse date
        if( filename.indexOf( dateRegExp ) >= 0 )
        { extensions.append( dateRegExp.capturedTexts().front() ); }

    }

    bool migrated = false;
    for( const auto& extension:extensions )
    { migrated |= ResourceMigration( source_ + extension ).migrate( destination+extension ); }

    return migrated;

}
