#ifndef ChatMessageSet_h
#define ChatMessageSet_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ChatMessage.h"
#include "Counter.h"
#include "File.h"
#include "TimeStamp.h"
#include "XmlDocument.h"

#include <QSet>

//_____________________________________________________
class ChatMessageSet: public Counter
{

    public:

    //* constructor
    ChatMessageSet( void );

    //*@name accessor
    //@{

    //* db file
    File filename( void ) const
    { return filename_; }

    //* db file
    File filenameNew( void ) const
    { return filenameNew_; }

    //* list of all opened filenames
    using FileSet = QSet<File>;
    FileSet filenames( void ) const
    { return filenames_; }

    //* true if compression is used
    bool useCompression( void ) const
    { return useCompression_; }

    //* messages
    const ChatMessage::Set& messages( void ) const
    { return messages_; }

    /**
    returns true if fetching messages starting from given timestamp
    requires openning/uncompressing new files
    */
    bool needsReading( const TimeStamp& ) const;

    //* messages matching a given timestamp and list of recipients
    ChatMessage::List fetch( const TimeStamp&, const QStringList& ) const;

    //@}

    //*@name modifiers
    //@{

    //* db file
    /** returns true if changed */
    bool setFilename( File );

    //* compression
    void setUseCompression( bool value )
    { useCompression_ = value; }

    //* read messages
    bool read( const TimeStamp& = TimeStamp() );

    //* write messages
    bool write( void );

    //* read messages from provided file
    bool read( const File&, ChatMessage::Set& ) const;

    //* write messages to file
    bool write( const File&, const ChatMessage::Set& ) const;

    //* append a message
    void append( const ChatMessage& );

    //* debug level
    void setDebugLevel( int value )
    { debugLevel_ = value; }

    //* compress all files
    void compress( void ) const;

    //* uncompress all files
    void uncompress( void ) const;

    //* merge new messages to older files
    bool mergeMessages( void ) const;

    //* clear new messages
    void clearNewMessages( void )
    { newMessages_.clear(); }

    //@}

    private:

    //* get filename matching a given timestamp
    QString _filename( const TimeStamp& ) const;

    //* get list of all filenames on disk after timeStamp
    QStringList _filenames( const TimeStamp& ) const;

    //* read Xml document from QFile
    bool _readXmlDocument( const File&, XmlDocument& ) const;

    //* add message to internal storing
    void _append( const ChatMessage&, ChatMessage::Set& ) const;

    //* filename
    File filename_;

    //* filename for new messages
    File filenameNew_;

    //* list of opened files
    FileSet filenames_;

    //* debug level
    int debugLevel_ = 1;

    //* compression
    bool useCompression_ = false;

    //* true when message set was modified and needs saving
    bool modified_ = false;

    //* messages
    ChatMessage::Set messages_;

    //* new messages
    ChatMessage::Set newMessages_;

};

#endif
