#ifndef ChatMessageThread_h
#define ChatMessageThread_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "ChatMessageSet.h"
#include "TimeStamp.h"

#include <QThread>

//* independent thread used to automatically save file
class ChatMessageThread: public QThread, public Counter
{

    Q_OBJECT

    public:

    //* constructor
    ChatMessageThread( QObject* = nullptr );

    //*@name modifiers
    //@{

    //* setup
    void setup( const ChatMessageSet& messages, const TimeStamp&, const QStringList& );

    //@}


    //*@name accessors
    //@{

    //* recipients
    const QStringList& recipients( void ) const
    { return recipients_; }

    //* messages
    const ChatMessageSet& messages( void ) const
    { return messages_; }

    //* message list
    const ChatMessage::List& messageList( void ) const
    { return messageList_; }

    //@}

    protected:

    //* Check files validity. Post a ValidFileEvent when finished
    virtual void run( void );

    private:

    //* messages
    ChatMessageSet messages_;

    //* fetch timestamp
    TimeStamp timestamp_;

    //* recipients
    QStringList recipients_;

    //* found messages
    ChatMessage::List messageList_;

};
#endif
