/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ContactList.h"
#include "ContactToolTipWidget.h"
#include "ContactListModel.h"

//_____________________________________________________________
ContactList::ContactList( QWidget* parent ):
    SimpleListView( parent )
{

    // selection mode
    setSelectionMode( SimpleListView::ContiguousSelection );

    // tooltip widget
    toolTipWidget_ = new ContactToolTipWidget( this );

    // connections
    connect( this, SIGNAL(hovered(QModelIndex)), SLOT(_showToolTip(QModelIndex)) );

}


//______________________________________________________
void ContactList::_showToolTip( const QModelIndex& index )
{

    if( !( model() && index.isValid() ) ) toolTipWidget_->hide();
    else if( ContactListModel* model = qobject_cast<ContactListModel*>( this->model() ) )
    {

        // fileInfo
        const ConnectionId connectionId( model->get( index ) );

        // icon
        QIcon icon( model->icon( connectionId ) );

        // rect
        QRect rect( visualRect( index ) );
        rect.translate( viewport()->mapToGlobal( QPoint( 0, 0 ) ) );
        toolTipWidget_->setIndexRect( rect );

        // assign to tooltip widget
        toolTipWidget_->setConnectionId( connectionId, icon );

        // show
        toolTipWidget_->showDelayed();

    }

}
