/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ContactListMenu.h"

#include "ClientApplication.h"
#include "ContactListWindow.h"
#include "Debug.h"
#include "DebugMenu.h"
#include "FileTransferManager.h"
#include "Singleton.h"

//__________________________________________________
ContactListMenu::ContactListMenu( QWidget* parent ):
    QMenuBar( parent ),
    Counter( "ContactListMenu" )
{

    Debug::Throw( "ContactListMenu::ContactListMenu" );

    // generic menu
    QMenu *menu;

    auto application( Singleton::get().application<ClientApplication>() );
    auto contactListWindow = qobject_cast<ContactListWindow*>( window() );

    // file
    menu = addMenu( tr( "File" ) );
    menu->addAction( &application->closeAction() );

    // tools menu
    menu = addMenu( tr( "Tools" ) );
    menu->addAction( &contactListWindow->pingServerAction() );
    menu->addAction( &contactListWindow->pingClientsAction() );
    menu->addSeparator();
    menu->addAction( &contactListWindow->fetchContactsAction() );

    // create Settings menu
    menu = addMenu( tr( "Settings" ) );

    // this should go to application, or ClientListWindow
    #if WITH_PULSEAUDIO
    menu->addAction( &application->toggleSoundAction() );
    #endif
    menu->addAction( &contactListWindow->toggleIdleTimeAction() );
    menu->addSeparator();
    menu->addAction( &application->configurationAction() );

    // create help menu
    menu = addMenu( tr( "Help" ) );
    menu->addAction( &application->aboutAction() );
    menu->addAction( &application->aboutQtAction() );

    // debug menu
    menu->addSeparator();
    DebugMenu *debugMenu( new DebugMenu( menu ) );
    menu->addAction( debugMenu->menuAction() );
    debugMenu->menuAction()->setVisible( false );

}
