#ifndef ContactListModel_h
#define ContactListModel_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "ListModel.h"
#include "ConnectionId.h"

#include <QHash>
#include <QIcon>

//* connection model
class ContactListModel: public ListModel<ConnectionId>, public Counter
{

    Q_OBJECT

    public:

    //* column types
    enum ColumnTypes
    {
        Name,
        Host,
        ConnectionTime,
        DisconnectionTime,
        nColumns
    };

    //* constructor
    ContactListModel( QObject* = nullptr );

    //*@name accessors
    //@{

    //* flags
    virtual Qt::ItemFlags flags(const QModelIndex &index) const
    {
        if (!index.isValid()) return Qt::ItemFlags();
        else return Qt::ItemIsEnabled;
    }

    //* data
    virtual QVariant data(const QModelIndex&, int) const;

    //* header data
    virtual QVariant headerData(int, Qt::Orientation, int = Qt::DisplayRole) const;

    //* icon matching a given user state
    QIcon icon( const ConnectionId& ) const;

    //* number of columns for a given index
    virtual int columnCount(const QModelIndex& = QModelIndex()) const
    { return nColumns; }

    //* returns true if there are some pending messages
    bool hasPendingMessages( void ) const;

    //* get number of pending messages for a given contact
    int pendingMessages( ConnectionId ) const;

    //* get number of pending transfer requests for given contact
    int pendingTransferRequests( ConnectionId ) const;

    //*

    //@}

    //*@name modifiers
    //@{

    //* set avatar
    void setAvatar( ConnectionId, QPixmap );

    //* clear pending messages and file transfer requests for a given contact
    void clearPendingMessages( ConnectionId );

    //* add one to the number of pending messages for a given contact
    void incrementPendingMessages( ConnectionId );

    //* add one to the number of file transfer requests for a given contact
    void incrementFileTransferRequests( ConnectionId );

    //* remove one to the number of file transfer requests for a given contact
    void decrementFileTransferRequests( ConnectionId );

    //*

    protected:

    //* sort
    virtual void _sort( int, Qt::SortOrder = Qt::AscendingOrder )
    {}

    private:

    //* list column names
    static const QString columnTitles_[nColumns];

    //* maps contacts and avatar
    struct IconList
    {
        QIcon normal;
        QIcon away;
        QIcon disabled;
    };

    using AvatarHash = QHash<ConnectionId, IconList>;
    AvatarHash avatars_;

    //* maps contacts and number of pending messages
    using ContactHash = QHash<ConnectionId, int>;
    ContactHash pendingMessages_;
    ContactHash fileTransferRequests_;

};

#endif
