#ifndef ContactToolTipWidget_h
#define ContactToolTipWidget_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseToolTipWidget.h"
#include "ConnectionId.h"

#include <QIcon>
#include <QFrame>
#include <QLabel>

class GridLayoutItem;

class ContactToolTipWidget: public BaseToolTipWidget
{

    Q_OBJECT

    public:

    //* constructor
    ContactToolTipWidget( QWidget* );

    //* set data
    void setConnectionId( const ConnectionId&, QIcon );

    //* mask
    void setPixmapSize( int value )
    {
        if( pixmapSize_ == value ) return;
        pixmapSize_ = value;
        _reload();
    }

    private Q_SLOTS:

    //* update configuration
    void _updateConfiguration( void );

    private:

    //* reload
    virtual void _reload( void )
    { setConnectionId( connectionId_, icon_ ); }

    //* time string
    QString _timeString( const TimeStamp& ) const;

    //* pixmap size
    int pixmapSize_ = 48;

    //* local icon copy
    QIcon icon_;

    //* connection id
    ConnectionId connectionId_;

    //* icon label
    QLabel* iconLabel_ = nullptr;

    //* file name label
    QLabel* userNameLabel_ = nullptr;

    //* separator
    QFrame* separator_ = nullptr;

    //*@name items
    //@{
    GridLayoutItem* hostItem_ = nullptr;
    GridLayoutItem* connectionTimeItem_ = nullptr;
    GridLayoutItem* disconnectionTimeItem_ = nullptr;
    //@}

};

#endif
