/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ConversationWindowMenu.h"

#include "ClientApplication.h"
#include "ContactListWindow.h"
#include "Debug.h"
#include "DebugMenu.h"
#include "FileTransferManager.h"
#include "ConversationWindow.h"
#include "MessageEditorWidget.h"
#include "Singleton.h"

//__________________________________________________
ConversationWindowMenu::ConversationWindowMenu( QWidget* parent ):
    QMenuBar( parent ),
    Counter( "ConversationWindowMenu" )
{

    Debug::Throw( "ConversationWindowMenu::ConversationWindowMenu" );

    // generic menu
    QMenu *menu;

    auto application( Singleton::get().application<ClientApplication>() );
    auto conversationWindow( qobject_cast<ConversationWindow*>( window() ) );
    ContactListWindow& contactListWindow( application->contactListWindow() );

    // file
    menu = addMenu( tr( "File" ) );
    menu->addAction( &conversationWindow->closeWindowAction() );
    // menu->addAction( &application->closeAction() );

    // tools menu
    menu = addMenu( tr( "Tools" ) );
    menu->addAction( &conversationWindow->reloadAction() );
    menu->addSeparator();
    menu->addAction( &conversationWindow->fileTransferManager().visibilityAction() );
    menu->addAction( &contactListWindow.visibilityAction() );

    // create Settings menu
    menu = addMenu( tr( "Settings" ) );
    #if WITH_PULSEAUDIO
    menu->addAction( &application->toggleSoundAction() );
    #endif
    #if USE_ASPELL
    menu->addAction( &conversationWindow->messageEditorWidget().autoSpellAction() );
    menu->addAction( &conversationWindow->messageEditorWidget().dictionaryMenuAction() );
    menu->addSeparator();
    menu->addAction( &application->configurationAction() );
    menu->addAction( &application->spellCheckConfigurationAction() );
    #else
    menu->addAction( &application->configurationAction() );
    #endif

    // create help menu
    menu = addMenu( tr( "Help" ) );
    menu->addAction( &application->aboutAction() );
    menu->addAction( &application->aboutQtAction() );

    // debug menu
    menu->addSeparator();
    DebugMenu *debugMenu( new DebugMenu( menu ) );
    menu->addAction( debugMenu->menuAction() );
    debugMenu->menuAction()->setVisible( false );

}
