/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ChatMessageSet.h"
#include "Color.h"
#include "DefaultFolders.h"
#include "File.h"
#include "HistoryMenu.h"
#include "IconSize.h"
#include "Util.h"
#include "XmlOptions.h"

#include <QHostAddress>

//_____________________________________________________
//* Default options installer
void installDefaultOptions( void )
{
    // set options default values
    XmlOptions::get().setAutoDefault( true );

    XmlOptions::get().keep( "OPEN_LINK_APPLICATIONS" );
    XmlOptions::get().keep( "OPEN_FILE_APPLICATIONS" );

    // history
    XmlOptions::get().set( "OLD_HISTORY_FILE", Option( File(".homechat-serverdb").addPath(Util::home()), Option::None ), true );
    XmlOptions::get().set( "HISTORY_FILE", Option( File("homechat/history").addPath(Util::config()) ), Option::None );
    XmlOptions::get().set<bool>( "COMPRESS_HISTORY", true );

    // server connection
    XmlOptions::get().setRaw( "CHAT_HOST", QHostAddress( QHostAddress::LocalHost ).toString() );
    XmlOptions::get().set<int>( "CHAT_PORT", 2078 );

    // ssh tunnel connection
    XmlOptions::get().set<bool>( "USE_SSH", false );
    XmlOptions::get().set<bool>( "SSH_REMEMBER_PASSWORD", false );
    XmlOptions::get().setRaw( "SSH_USERNAME", Util::user() );
    XmlOptions::get().setRaw( "SSH_HOST", QHostAddress( QHostAddress::LocalHost ).toString() );
    XmlOptions::get().set<int>( "SSH_PORT", 22 );

    // flags
    XmlOptions::get().set<bool>( "USE_NOTIFICATIONS", true );
    XmlOptions::get().set<bool>( "USE_SOUND_NOTIFICATIONS", false );
    XmlOptions::get().set<bool>( "NOTIFY_USER_TYPING", true );
    XmlOptions::get().set<bool>( "USE_SYSTEMTRAY", true );
    XmlOptions::get().set<bool>( "START_HIDDEN", false );
    XmlOptions::get().set<bool>( "AUTO_CONNECT", true );

    XmlOptions::get().set<int>( "SOUND_NOTIFICATION_MASK", 0xf );

    // idle time
    // minutes
    XmlOptions::get().set<int>( "IDLE_TIMEOUT", 10 );
    XmlOptions::get().set<bool>( "DETECT_IDLE_TIME",  true );

    // time outs
    // seconds
    XmlOptions::get().set<int>( "AUTHORIZATION_TIMEOUT", 10 );
    XmlOptions::get().set<int>( "PING_TIMEOUT", 10 );
    XmlOptions::get().set<int>( "AUTOSAVE_TIMEOUT", 10 );
    XmlOptions::get().set<int>( "FULLSAVE_TIMEOUT", 6 ); // hours

    XmlOptions::get().set<int>( "CHECK_CONNECTIONS_TIMEOUT", 10 );
    XmlOptions::get().set<int>( "RECONNECT_TIMEOUT", 1 );

    // file transfer save location
    DefaultFolders::get().initializeFolderNames();
    File downloadDirectory = DefaultFolders::get().file( DefaultFolders::Downloads );
    if( downloadDirectory.isNull() ) downloadDirectory = Util::home();
    XmlOptions::get().setRaw( "DOWNLOAD_LOCATION", downloadDirectory );

    XmlOptions::get().set<bool>( "AUTOCLOSE_EMISSION_TRANSFERS", false );

    // appearance
    XmlOptions::get().set<bool>( "SHOW_LINKS", true );
    XmlOptions::get().set<bool>( "USE_EMOTICONS", true );
    XmlOptions::get().set<bool>( "COLORIZE_EMOTICONS", true );
    XmlOptions::get().set<int>( "EMOTICON_SIZE", 15 );

    XmlOptions::get().set<bool>( "SHOW_TOOLTIPS", true );
    XmlOptions::get().set<int>( "TOOLTIPS_PIXMAP_SIZE", 96 );

    XmlOptions::get().set<bool>( "FLAT_CONTACT_LIST", false );
    XmlOptions::get().set<bool>( "HORIZONTAL_CONTACT_LIST", false );

    // avatar
    XmlOptions::get().set( "AVATAR_PATH", File("homechat/").addPath( Util::config() ), Option::None );

    // history
    XmlOptions::get().set<int>( "DEFAULT_HISTORY_SPAN", HistoryMenu::OneDay );

    // user colors
    XmlOptions::get().keep( "USER_COLOR" );
    XmlOptions::get().add( "USER_COLOR", Option().set<Base::Color>( QColor( "#2980B9" ) ) );
    XmlOptions::get().add( "USER_COLOR", Option().set<Base::Color>( QColor( "#14405C" ) ) );
    XmlOptions::get().add( "USER_COLOR", Option().set<Base::Color>( QColor( "#F67400" ) ) );
    XmlOptions::get().add( "USER_COLOR", Option().set<Base::Color>( QColor( "#DA4453" ) ) );

    #ifdef USE_ASPELL
    XmlOptions::get().set<bool>( "AUTOSPELL_ENABLED", true );
    XmlOptions::get().set( "DICTIONARY", "en" );
    XmlOptions::get().set( "DICTIONARY_FILTER", "none" );
    XmlOptions::get().set( "AUTOSPELL_COLOR", "red" );
    XmlOptions::get().set<int>( "AUTOSPELL_FONT_FORMAT", 0 );
    XmlOptions::get().set<int>( "MAX_SUGGESTIONS", 0 );
    #endif

    XmlOptions::get().setAutoDefault( false );
}
