/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Emoticon.h"

#include <QPainter>
#include <QPalette>
//_________________________________________________________________
Emoticon::Emoticon( const QRegExp& regexp, const QStringList& strings, const QString& filename, const QString& description ):
    Counter( "Emoticon" ),
    regexp_( regexp ),
    strings_( strings ),
    resourceName_( filename ),
    description_( description ),
    icon_( filename )
{}

//_________________________________________________________________
void Emoticon::setIconSize( const QSize& size )
{
    if( size != iconSize_ )
    {
        iconSize_ = size;
        _updateImage();
    }
}

//_________________________________________________________________
void Emoticon::setColorize( bool value )
{
    if( value != colorize_ )
    {
        colorize_ = value;
        _updateImage();
    }

}

//______________________________________________________________
QPixmap Emoticon::colorize( QPixmap source, QColor color )
{
    QPixmap out( source );
    QPainter painter( &out );
    painter.setCompositionMode( QPainter::CompositionMode_SourceIn );
    painter.setBrush( color );
    painter.setPen( Qt::NoPen );
    painter.drawRect( out.rect() );
    painter.end();
    return out;
}

//_________________________________________________________________
void Emoticon::_updateImage( void )
{
    // get pixmap
    QPixmap pixmap( icon_.pixmap( iconSize_ ) );
    if( colorize_ ) pixmap = colorize( pixmap, QPalette().color( QPalette::Text ) );

    // create image
    image_ = QImage( iconSize_ + QSize(1,1), QImage::Format_ARGB32_Premultiplied );
    image_.fill( Qt::transparent );

    QPainter painter( &image_ );
    painter.drawPixmap( QPoint(0,1), pixmap );
}
