#ifndef Emoticon_h
#define Emoticon_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"

#include <QIcon>
#include <QImage>
#include <QRegExp>
#include <QStringList>
#include <QVector>

class Emoticon: public Counter
{

    public:

    //* constructor
    Emoticon( void ):
        Counter( "Emoticon" )
    {}

    //* constructor
    Emoticon( const QRegExp& regexp, const QStringList& strings, const QString& filename, const QString& description = QString() );

    //* true if valid
    bool isValid( void ) const
    { return regexp_.isValid() && !strings_.isEmpty() && !resourceName_.isNull(); }

    //*@name accessors
    //@{

    const QRegExp& regExp( void ) const
    { return regexp_; }

    const QStringList& strings( void ) const
    { return strings_; }

    const QString& resourceName( void ) const
    { return resourceName_; }

    const QString& description( void ) const
    { return description_; }

    QIcon icon( void ) const
    { return icon_; }

    QImage image( void ) const
    { return image_; }

    //@}

    //*@name modifiers
    //@{

    void setColorize( bool );

    void setIconSize( const QSize& );

    //@}

    //*@name utilities
    //@{

    static QPixmap colorize( QPixmap, QColor );

    //@}

    using List = QVector<Emoticon>;

    private:

    //* update image
    void _updateImage( void );

    //* matching regexp
    QRegExp regexp_;

    //* maching sring
    QStringList strings_;

    //* resource name
    QString resourceName_;

    //* description
    QString description_;

    //* colorize
    bool colorize_ = false;

    //* icon size
    QSize iconSize_;

    //* icon
    QIcon icon_;

    //* image
    QImage image_;

};

#endif
