/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "EmoticonButton.h"

#include "Emoticon.h"
#include "Singleton.h"
#include "XmlOptions.h"

#include <QStylePainter>
#include <QStyleOptionToolButton>

//____________________________________________________________
EmoticonButton::EmoticonButton( QWidget* parent ):
    CustomToolButton( parent )
{
    Debug::Throw("EmoticonButton::EmoticonButton.\n" );
    // setMouseTracking( true );


    // configuration
    connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
    _updateConfiguration();

}

//____________________________________________________________
bool EmoticonButton::event( QEvent* event )
{
    if( !(parent() && parent()->inherits( "EmoticonWidget" ) ) )
    { return CustomToolButton::event( event ); }

    switch( event->type() )
    {
        case QEvent::HoverEnter:
        case QEvent::HoverMove:
        if( !hasFocus() ) setFocus();
        break;

        default: break;
    }

    return CustomToolButton::event( event );

}

//____________________________________________________________
void EmoticonButton::paintEvent( QPaintEvent* event )
{

    if( !colorize_ ) return CustomToolButton::paintEvent( event );

    // rotated paint
    QStylePainter painter(this);
    QStyleOptionToolButton option;
    initStyleOption(&option);

    option.icon = Emoticon::colorize( option.icon.pixmap( option.iconSize ), palette().color( QPalette::ButtonText ) );
    painter.drawComplexControl(QStyle::CC_ToolButton, option);

}

//____________________________________________________________
void EmoticonButton::keyReleaseEvent( QKeyEvent* event )
{
    Debug::Throw( "EmoticonButton::keyReleaseEvent.\n" );
    if( event->key() == Qt::Key_Return )
    {
        click();
        return;
    } else return CustomToolButton::keyReleaseEvent( event );
}

//____________________________________________________________
void EmoticonButton::_updateConfiguration( void )
{
    Debug::Throw( "EmoticonButton::_updateConfiguration" );
    if( colorizeFromOptions_ )
    { colorize_ = XmlOptions::get().get<bool>( "COLORIZE_EMOTICONS" ); }
}
