#ifndef EmoticonProvider_h
#define EmoticonProvider_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Emoticon.h"

#include <QHash>
#include <QObject>
#include <QRegExp>
#include <QTextCursor>
#include <QTextDocument>

class EmoticonProvider: public QObject, public Counter
{

    Q_OBJECT

    public:

    //* constructor
    EmoticonProvider( QObject* );

    //*@name accessors
    //@{

    //* true if enabled
    bool isEnabled( void ) const
    { return enabled_; }

    //* get list of emoticons
    const Emoticon::List& emoticons( void ) const
    { return emoticons_; }

    //*}

    //*@name modifiers
    //@{

    //* enable
    bool setEnabled( bool value )
    {
        if( enabled_ == value ) return false;
        enabled_ = value;
        return true;
    }

    //* icon size
    bool setIconSize( int );

    //* icon size
    bool setColorize( bool );

    //@}

    //* install resources in document
    void installResources( QTextDocument* ) const;

    //* replace icons in text from cursor
    void process( QTextCursor );

    //* parse text, replace images by emoticon text
    QString revert( QTextCursor, bool& changed ) const;

    protected:

    //* resource name for a given emoticon
    QString _resourceName( const Emoticon& ) const;

    private:

    //* true if enabled
    bool enabled_ = true;

    //* icon size
    int iconSize_ = 0;

    //* colorize
    bool colorize_ = false;

    //* general regexp
    QRegExp regexp_;

    //* emoticons
    Emoticon::List emoticons_;

    //* map string to emoticon
    using EmoticonMap = QHash<QString, Emoticon>;
    EmoticonMap emoticonMap_;

};


#endif
