/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "EmoticonSelectionMenu.h"
#include "EmoticonSelectionMenu_p.h"

#include "EmoticonButton.h"
#include "EmoticonProvider.h"
#include "GridLayout.h"

//____________________________________________________________
namespace Private
{
    EmoticonWidget::EmoticonWidget( QWidget* parent ):
        QWidget( parent ),
        Counter( "EmoticonWidget" )
    {

        // main widget
        GridLayout* gridLayout = new GridLayout();
        gridLayout->setMargin(0);
        gridLayout->setSpacing(0);
        gridLayout->setMaxCount(3);
        setLayout( gridLayout );

        buttonGroup_ = new QButtonGroup( this );

        EmoticonProvider provider( this );
        for( const auto& emoticon:provider.emoticons() )
        {
            CustomToolButton* toolButton = new EmoticonButton( this );
            toolButton->setIcon( QIcon( emoticon.resourceName() ) );
            toolButton->setToolTip( emoticon.description() + " " + emoticon.strings().first() );
            buttonGroup_->addButton( toolButton );
            buttons_.insert( toolButton, emoticon );
            gridLayout->addWidget( toolButton );
        }
    }

    //____________________________________________________________
    QWidget* EmoticonAction::createWidget( QWidget* parent )
    {
        widget_ = new EmoticonWidget( parent );
        connect( &widget_->buttonGroup(), SIGNAL(buttonClicked(QAbstractButton*)), SLOT(_buttonClicked(QAbstractButton*)) );
        return widget_;
    }

    //____________________________________________________________
    void EmoticonAction::_buttonClicked( QAbstractButton* button )
    {
        const auto& buttons( widget_->buttons() );
        auto iter( buttons.find( button ) );
        if( iter != buttons.end() )
        { emit emoticonSelected( iter.value() ); }
    }

}

//____________________________________________________________
EmoticonSelectionMenu::EmoticonSelectionMenu( QWidget* parent ):
    QMenu( parent ),
    Counter( "EmoticonSelectionMenu" )
{

    // widget action
    action_ = new Private::EmoticonAction( this );
    addAction( action_ );
    connect( this, SIGNAL(aboutToShow()), this, SLOT(_updateButtonFocus()) );
    connect( action_, SIGNAL(emoticonSelected(Emoticon)), this, SIGNAL(emoticonSelected(Emoticon)) );
    connect( action_, SIGNAL(emoticonSelected(Emoticon)), this, SLOT(close()) );

}

//____________________________________________________________
void EmoticonSelectionMenu::_updateButtonFocus( void )
{
    Debug::Throw( "EmoticonSelectionMenu::_updateButtonFocus.\n" );
    action_->widget().buttonGroup().buttons().front()->setFocus();
}
