#ifndef EmoticonSelectionMenu_p_h
#define EmoticonSelectionMenu_p_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include <QButtonGroup>
#include <QKeyEvent>
#include <QWidgetAction>

namespace Private
{

    class EmoticonWidget: public QWidget, public Counter
    {
        Q_OBJECT

        public:

        //* constructor
        EmoticonWidget( QWidget* );

        //*@name accessors
        //@{

        //* button group
        QButtonGroup& buttonGroup( void ) const
        { return *buttonGroup_; }

        //* button map
        using ButtonMap = QMap<QAbstractButton*, Emoticon>;
        const ButtonMap& buttons( void ) const
        { return buttons_; }

        //@}

        private:

        //* button group
        QButtonGroup* buttonGroup_ = nullptr;

        //* buttons
        ButtonMap buttons_;

    };

    class EmoticonAction: public QWidgetAction, public Counter
    {

        Q_OBJECT

        public:

        //* constructor
        EmoticonAction( QObject* parent ):
            QWidgetAction( parent ),
            Counter( "EmoticonAction" )
        {}

        //* widget accessor
        const EmoticonWidget& widget( void ) const
        { return *widget_; }

        protected:

        //* create widget
        QWidget* createWidget( QWidget* parent );

        Q_SIGNALS:

        //* emoticon selected
        void emoticonSelected(Emoticon);

        protected Q_SLOTS:

        //* button clicked
        void _buttonClicked( QAbstractButton* );

        private:

        //* widget
        EmoticonWidget* widget_ = nullptr;

    };

}
#endif
