/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FileChunk.h"
#include "Debug.h"

//___________________________________________
FileChunk::FileChunk( const ConnectionId& connectionId, File filename ):
    BaseChatCommand( connectionId ),
    filename_( filename )
{ Debug::Throw( "FileChunk::FileChunk.\n" ); }

//__________________________________________________
QDataStream& operator << (QDataStream& stream, const FileChunk& fileChunk )
{
    static const quint32 version = 0;

    stream

        // version
        << version

        // base class members
        << fileChunk.clientId()
        << fileChunk.connectionId()
        << fileChunk.recipients()

        // members
        << QString( fileChunk.filename_ )
        << quint32( fileChunk.flags_ )
        << fileChunk.data_;

    return stream;
}

//__________________________________________________
QDataStream& operator >> (QDataStream& stream, FileChunk& fileChunk )
{
    quint32 version;
    stream >> version;

    if( version == 0 )
    {

        quint32 clientId;
        ConnectionId connectionId;
        QStringList recipients;
        QString filename;
        quint32 flags;
        stream

            // base class members
            >> clientId
            >> connectionId
            >> recipients

            // class members
            >> filename
            >> flags
            >> fileChunk.data_;

        fileChunk.setClientId( clientId );
        fileChunk.setConnectionId( connectionId );
        fileChunk.setRecipients( recipients );
        fileChunk.filename_ = File( filename );
        fileChunk.flags_ = (FileChunk::Flags) flags;

    } else Debug::Throw(0) << "Unrecognized FileChunk version: " << version << endl;
    return stream;
}
