#ifndef FileChunk_h
#define FileChunk_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseChatCommand.h"
#include "ConnectionId.h"
#include "File.h"

#include <QByteArray>
#include <QDataStream>

//_________________________________________
//* command to be send over the server
class FileChunk:public BaseChatCommand
{

    public:

    //* constructor
    FileChunk( const ConnectionId& = ConnectionId(), File = File() );

    //* status flags
    enum Flag
    {
        None = 0,
        First = 1<<0,
        Last = 1<<1,
        Hash = 1<<2
    };

    Q_DECLARE_FLAGS( Flags, Flag );


    //*@name accessors
    //@{

    //* filename
    File filename( void ) const
    { return filename_; }

    //* flags
    Flags flags( void ) const
    { return flags_; }

    //* data
    const QByteArray& data( void ) const
    { return data_; }

    //* size
    int size( void ) const
    { return data_.size(); }

    //@}

    //*@name modifiers
    //@{

    //* filename
    void setFilename( const File& value )
    { filename_ = value; }

    //* flags
    void setFlags( Flags value )
    { flags_ = value; }

    //* data
    void setData( const QByteArray& value )
    { data_ = value; }

    //@}

    private:

    //* filename
    File filename_;

    //* flags
    Flags flags_ = 0;

    //* data
    QByteArray data_;

    //*@name serializers
    //@{
    friend QDataStream& operator << (QDataStream&, const FileChunk& );
    friend QDataStream& operator >> (QDataStream&, FileChunk& );
    //@}

};

Q_DECLARE_OPERATORS_FOR_FLAGS( FileChunk::Flags );

#endif
