/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FileEmissionClient.h"
#include "FileEmissionThread.h"
#include "Debug.h"

//_______________________________________________________
FileEmissionClient::FileEmissionClient( QObject* parent ):
    ChatClient( parent ),
    thread_( new FileEmissionThread( this ) )
{
    Debug::Throw( "FileEmissionClient::FileEmissionClient.\n" );

    connect( thread_, SIGNAL(fileChunkAvailable(FileChunk)), this, SLOT(sendFileChunk(FileChunk)) );
    connect( thread_, SIGNAL(fileChunkAvailable(FileChunk)), this, SIGNAL(fileChunkAvailable(FileChunk)) );
    connect( thread_, SIGNAL(finished()), this, SLOT(_finish()) );
    connect( &socket(), SIGNAL(disconnected()), this, SIGNAL(finished()) );

}

//_______________________________________________________
BaseFileInfo FileEmissionClient::fileInfo( void ) const
{ return thread_->fileInfo(); }

//_______________________________________________________
void FileEmissionClient::setConnectionId( const ConnectionId& value )
{
    ChatClient::setConnectionId( value );
    thread_->setConnectionId( value );
}

//_______________________________________________________
void FileEmissionClient::setFileInfo( const BaseFileInfo& value )
{ thread_->setFileInfo( value ); }

//_______________________________________________________
void FileEmissionClient::send( void )
{
    Debug::Throw( "FileEmissionClient::send.\n" );
    if( !thread_->isRunning() ) thread_->start();
}

//_______________________________________________________
void FileEmissionClient::cancel( void )
{
    Debug::Throw( "FileEmissionClient::cancel.\n" );

    // first disconnect thread
    disconnect( thread_, SIGNAL(fileChunkAvailable(FileChunk)) );
    disconnect( thread_, SIGNAL(finished()) );

    // try terminate thread
    if( thread_->isRunning() )
    {
        thread_->terminate();
        thread_->wait();
    }

    // disconnect socket
    socket().disconnectFromHost();

}

//_______________________________________________________
void FileEmissionClient::_finish( void )
{ socket().disconnectFromHost(); }
