/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FileEmissionThread.h"

#include <QFile>
#include <QMetaType>

//______________________________________________________
FileEmissionThread::FileEmissionThread( QObject* parent ):
    QThread( parent ),
    Counter( "FileEmissionThread" ),
    hash_( QCryptographicHash::Md5 )
{ qRegisterMetaType<FileChunk>( "FileChunk" ); }

//______________________________________________________
void FileEmissionThread::run( void )
{

    // open file
    Q_ASSERT( connectionId_.isValid() && fileInfo_.isValid() );

    // open file
    const File filename = fileInfo_.file();

    QFile file( filename );
    if( !file.open( QIODevice::ReadOnly ) ) return;

    // chunk size is hard coded to 64k
    static const qint64 chunkSize = 1<<16;

    bool first = true;
    while( !file.atEnd() )
    {

        QByteArray array = file.read( chunkSize );
        if( array.isEmpty() ) break;

        // add data to hash
        hash_.addData( array );

        // create file chunk and assign data
        FileChunk fileChunk( connectionId_, filename );
        fileChunk.setData( array );

        // setup flags
        FileChunk::Flags flags = 0;
        if( first )
        {
            flags |= FileChunk::First;
            first = false;
        }

        fileChunk.setFlags( flags );
        emit fileChunkAvailable( fileChunk );

    }

    file.close();

    // at end of file emit hash
    FileChunk fileChunk( connectionId_, filename );
    fileChunk.setFlags( FileChunk::Hash | FileChunk::Last );
    fileChunk.setData( hash_.result() );
    emit fileChunkAvailable( fileChunk );

}
