#ifndef FileEmissionThread_h
#define FileEmissionThread_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseFileInfo.h"
#include "ConnectionId.h"
#include "Counter.h"
#include "FileChunk.h"

#include <QThread>
#include <QCryptographicHash>

//* independent thread used to automatically save file
class FileEmissionThread: public QThread, public Counter
{

    Q_OBJECT

    public:

    //* constructor
    FileEmissionThread( QObject* );

    //*@name accessors
    //@{

    //* connection id
    ConnectionId connectionId( void ) const
    { return connectionId_; }

    //* file info
    BaseFileInfo fileInfo( void ) const
    { return fileInfo_; }

    //@}

    //*@name modifiers
    //@{

    //* connection id
    void setConnectionId( const ConnectionId& value )
    { connectionId_ = value; }

    //* file info
    void setFileInfo( const BaseFileInfo& value )
    { fileInfo_ = value; }

    //*}

    Q_SIGNALS:

    void fileChunkAvailable( FileChunk );

    protected:

    //* Check files validity. Post a ValidFileEvent when finished
    virtual void run( void );

    private:

    //* connection id
    ConnectionId connectionId_;

    //* filename
    BaseFileInfo fileInfo_;

    //* cryptographic hash
    QCryptographicHash hash_;

};
#endif
