/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FileReceptionClient.h"
#include "FileEmissionThread.h"
#include "Debug.h"

#include <QDataStream>

//_______________________________________________________
FileReceptionClient::FileReceptionClient( QObject* parent ):
    ChatClient( parent ),
    hash_( QCryptographicHash::Md5 )
{
    Debug::Throw( "FileReceptionClient::FileReceptionClient.\n" );
    connect( this, SIGNAL(fileChunkAvailable(FileChunk)), SLOT(_processFileChunk(FileChunk)) );
    connect( &socket(), SIGNAL(disconnected()), this, SIGNAL(finished()) );
}

//_______________________________________________________
void FileReceptionClient::setDestinationFile( const File& value )
{ destinationFile_ = new QFile( value, this ); }

//_______________________________________________________
void FileReceptionClient::cancel( void )
{

    Debug::Throw( "FileReceptionClient::cancel.\n" );

    // remove destination file
    if( destinationFile_->isOpen() ) destinationFile_->remove();

    // disconnect
    socket().disconnectFromHost();

}

//_______________________________________________________
void FileReceptionClient::_processFileChunk( FileChunk fileChunk )
{

    // get file from chunk and compare
    const File filename( fileChunk.filename() );
    Q_ASSERT( filename == fileInfo_.file() );

    // first chunk
    if( fileChunk.flags() & FileChunk::First )
    {

        Debug::Throw() << "FileReceptionClient::_processFileChunk - received first" << endl;

        // reset hash
        hash_.reset();
        emissionHash_.clear();

        // try open file
        if( !destinationFile_->open( QIODevice::WriteOnly ) )
        {
            socket().disconnectFromHost();
            return;
        }

    }

    if( fileChunk.flags() & FileChunk::Hash )
    {

        Debug::Throw() << "FileReceptionClient::_processFileChunk - received hash" << endl;
        emissionHash_ = fileChunk.data();

    } else {

        // write data
        destinationFile_->write( fileChunk.data() );
        hash_.addData( fileChunk.data() );

    }

    // close if needed
    if( fileChunk.flags() & FileChunk::Last )
    {

        Debug::Throw() << "FileReceptionClient::_processFileChunk - received last" << endl;
        destinationFile_->close();
        socket().disconnectFromHost();

        if( !( emissionHash_.isEmpty() || hash_.result() == emissionHash_ ) )
        {
            destinationFile_->remove();
            emit transferFailed();
        }

    }

}
