#ifndef FileReceptionClient_h
#define FileReceptionClient_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ChatClient.h"
#include "BaseFileInfo.h"
#include "FileChunk.h"

#include <QFile>
#include <QCryptographicHash>

//* interprocess communication client
class FileReceptionClient : public ChatClient
{

    //* Qt meta object macro
    Q_OBJECT

    public:

    //* constructor
    FileReceptionClient( QObject* );

    //*@name accessors
    //@{

    BaseFileInfo fileInfo( void ) const
    { return fileInfo_; }

    //@}

    //*@name modifiers
    //@{

    //* file info
    void setFileInfo( const BaseFileInfo& value )
    { fileInfo_ = value; }

    //* sender
    void setSender( const ConnectionId& value )
    { sender_ = value; }

    //* destination file
    void setDestinationFile( const File& );

    //*}

    Q_SIGNALS:

    //* emitted when transfer has failed
    void transferFailed( void );

    //* emitted when transfer is completed
    void finished( void );

    public Q_SLOTS:

    //* abort
    void cancel( void );

    protected Q_SLOTS:

    //* process file chunk
    void _processFileChunk( FileChunk );

    private:

    //* source file info
    BaseFileInfo fileInfo_;

    //* sender
    ConnectionId sender_;

    //* destination file
    QFile* destinationFile_ = nullptr;

    //* cryptographic hash
    QCryptographicHash hash_;

    //* emission hash
    QByteArray emissionHash_;

};

#endif
