#ifndef FileTransferManager_h
#define FileTransferManager_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseFileInfo.h"
#include "FileChunk.h"
#include "FileTransferWidget.h"

#include <QAction>
#include <QLabel>
#include <QLayout>
#include <QScrollArea>

class MimeTypeIconProvider;

//* file transfer request
class FileTransferManager: public QWidget
{

    Q_OBJECT

    public:

    //* constructor
    FileTransferManager( QWidget* = nullptr  );

    //*@name accessors
    //@{

    //* get file transfer widget matching a give file and mode
    FileTransferWidget* fileTransfer( const BaseFileInfo& fileInfo, FileTransferWidget::Mode mode ) const;

    //* visibility action
    QAction& visibilityAction( void ) const
    { return *visibilityAction_; }

    virtual QSize minimumSizeHint( void ) const
    { return sizeHint_; }

    virtual QSize sizeHint( void ) const
    { return sizeHint_; }

    //@}

    //*@name modifiers
    //@{

    //* register a file transfer
    FileTransferWidget* addFileTransfer( const BaseFileInfo& fileInfo, FileTransferWidget::Mode mode );

    //* update file transfer status
    void setStatus( const BaseFileInfo&, FileTransferWidget::Status, const QString& = QString() );

    //@}

    Q_SIGNALS:

    // emited when file transfer is added
    void fileTransferAdded(BaseFileInfo);

    // emited when transfer is manually cancelled
    void fileTransferCancelled(BaseFileInfo);

    private Q_SLOTS:

    //* check empty list
    void _checkEmptyList( void );

    //* update separators
    void _updateSeparators( void );

    private:

    //* install actions
    void _installActions( void );

    //* icon provider
    MimeTypeIconProvider* iconProvider_ = nullptr;

    //* title label
    QLabel* titleLabel_ = nullptr;

    //* scroll area
    QScrollArea* scrollArea_ = nullptr;

    //* main widget
    QWidget* mainWidget_ = nullptr;

    //* main layout
    QLayout* mainLayout_ = nullptr;

    //* visibility action
    QAction* visibilityAction_ = nullptr;

    //* size hint
    QSize sizeHint_;

};

#endif
