/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FileTransferRequestDialog.h"
#include "BaseIconNames.h"
#include "BrowsedLineEditor.h"
#include "IconEngine.h"
#include "LineEditor.h"
#include "XmlOptions.h"

#include <QLabel>
#include <QToolButton>

//________________________________________________________________________
FileTransferRequestDialog::FileTransferRequestDialog( QWidget* parent, ConnectionId id, BaseFileInfo fileInfo ):
    CustomDialog( parent, OkButton|CancelButton|Separator ),
    sender_( id ),
    fileInfo_( fileInfo )
{
    Debug::Throw( "FileTransferRequestDialog::FileTransferRequestDialog.\n" );
    okButton().setText( tr( "Accept" ) );

    // try load Question icon
    QHBoxLayout *hLayout( new QHBoxLayout() );
    hLayout->setSpacing(10);
    hLayout->setMargin(0);
    mainLayout().addLayout( hLayout );
    {
        QLabel* label = new QLabel( this );
        label->setPixmap( IconEngine::get( IconNames::DialogWarning ).pixmap( iconSize() ) );
        hLayout->addWidget( label, 0 );
    }

    // vertical layout for question etc.
    QVBoxLayout* vLayout = new QVBoxLayout();
    vLayout->setMargin(0);
    hLayout->addLayout( vLayout );

    const QString localName = fileInfo.file().localName();
    const QString sizeString = File::sizeString( fileInfo.size() );
    const QString message = tr( "Accept file \"%1\" from %2 (%3)?" ).arg( localName ).arg( id.user() ).arg( sizeString );

    QLabel* label;
    vLayout->addWidget( label = new QLabel( message, this ) );
    vLayout->addWidget( new QLabel( tr( "Download location:" ), this ) );

    {
        QHBoxLayout* hLayout = new QHBoxLayout();
        hLayout->setSpacing(5);
        vLayout->addLayout( hLayout );

        hLayout->addWidget( editor_ = new BrowsedLineEditor( this ) );
        editor_->editor().setReadOnly( true );
        editor_->setFileMode( QFileDialog::Directory );
        label->setBuddy( editor_ );

        // restore default button
        QToolButton *button = new QToolButton( this );
        button->setAutoRaise( true );
        button->setIcon( IconEngine::get( IconNames::Revert ) );
        button->setToolTip( tr( "Revert to default" ) );
        hLayout->addWidget( button, 0 );
        connect( button, SIGNAL(clicked()), SLOT(_restoreDefaultLocation()) );

    }

    _restoreDefaultLocation();

}

//________________________________________________________________________
File FileTransferRequestDialog::downloadLocation( void ) const
{ return File( editor_->editor().text() ); }

//________________________________________________________________________
void FileTransferRequestDialog::accept( void )
{
    Debug::Throw(0, "FileTransferRequestDialog::accept.\n" );
    emit acceptFileTransfer(sender_, fileInfo_, downloadLocation() );
    return CustomDialog::accept();
}


//________________________________________________________________________
void FileTransferRequestDialog::reject( void )
{
    Debug::Throw(0, "FileTransferRequestDialog::reject.\n" );
    emit denyFileTransfer(sender_, fileInfo_ );
    return CustomDialog::reject();
}

//________________________________________________________________________
void FileTransferRequestDialog::_restoreDefaultLocation( void )
{ editor_->setFile( File( XmlOptions::get().raw( "DOWNLOAD_LOCATION" ) ) ); }
