#ifndef FileTransferWidget_h
#define FileTransferWidget_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseFileInfo.h"
#include "FileChunk.h"

#include <QFrame>
#include <QLabel>
#include <QProgressBar>
#include <QStringList>
#include <QToolButton>

//* file transfer request
class FileTransferWidget: public QWidget
{

    Q_OBJECT

    public:

    //* transfer mode
    enum Mode
    {
        Emission,
        Reception
    };

    //* constructor
    FileTransferWidget( QWidget*, Mode );

    //*@name accessors
    //@{

    //* mode
    Mode mode( void ) const
    { return mode_; }

    //* file info
    const BaseFileInfo& fileInfo( void ) const
    { return fileInfo_; }

    enum Status
    {
        Unknown,
        Starting,
        Transferring,
        Completed,
        Cancelled,
        Failed
    };

    //* status
    Status status( void ) const
    { return status_; }

    //* separator widget
    QFrame& separator( void ) const
    { return *separator_; }

    //@}

    //*@name modifiers
    //@{

    //* set icon
    void setIcon( const QIcon& );

    //* file info
    void setFileInfo( const BaseFileInfo& );

    //* set destination
    void setDestination( const File& );

    //* recipients
    void setRecipients( const QStringList& value )
    {
        recipients_ = value;
        _updateButtons();
    }

    //* status
    void setStatus( Status, const QString& = QString() );

    //@}

    Q_SIGNALS:

    // emitted when transfer is manually cancelled
    void fileTransferCancelled(BaseFileInfo);

    // emitted when transfer is manually resent
    void fileTransferResent(QStringList, BaseFileInfo);

    public Q_SLOTS:

    //* process file chunk (sent or received)
    void processFileChunk( FileChunk );

    //* mark transfer as failed
    void setTransferFailed( void );

    private Q_SLOTS:

    //* update actions
    void _updateButtons( void );

    //* cancel
    void _cancel( void );

    //* resend
    void _resend( void );

    //* open
    void _open( void );

    private:

    //* install actions
    void _installButtons( void );

    //* status
    void _setStatusString( const QString& );

    //* mode
    Mode mode_ = Emission;

    //* filename
    BaseFileInfo fileInfo_;

    //* destination file
    File destination_;

    //* recipients
    QStringList recipients_;

    //* status
    Status status_ = Unknown;

    //* separator
    QFrame* separator_ = nullptr;

    //* icon label
    QLabel* iconLabel_ = nullptr;

    //* file label
    QLabel* fileLabel_ = nullptr;

    //* status label
    QLabel* statusLabel_ = nullptr;

    //* progress bar
    QProgressBar* progressBar_ = nullptr;

    //* open
    QToolButton* openWithButton_ = nullptr;

    //* resend
    QToolButton* resendButton_ = nullptr;

    //* cancel
    QToolButton* cancelButton_ = nullptr;

};

#endif
