#ifndef IdleTime_h
#define IdleTime_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"

#include <QObject>
#include <QBasicTimer>
#include <QTimerEvent>
#include <QThread>

class IdleTime: public QObject, public Counter
{

    Q_OBJECT

    public:

    //* constructor
    IdleTime( QObject* = nullptr );

    //*@name accessors
    //@{

    //* true if monitoring is supported
    bool isSupported( void ) const;

    //* true if running
    bool isRunning( void ) const;

    //* true if enabled
    bool isEnabled( void ) const
    { return timeout_ > 0; }

    //@}

    //*@name modifiers
    //@{

    //* timeout
    void setTimeout( int );

    //* start monitoring
    virtual void start( void );

    //* stop monitoring
    virtual void stop( void );

    //@}

    Q_SIGNALS:

    //* iddle state changed
    void idleStateChanged( bool );

    protected:

    //* timer event
    virtual void timerEvent( QTimerEvent* );

    protected Q_SLOTS:

    void _activityDetected( void );

    private:

    //* check idle time against timeout
    void _checkTimeout( void );

    //* ask X about how long system has been idle
    uint32_t _idleTime( void ) const;

    //* true if idle time is active
    bool isActive_ = false;

    //* timeout (ms)
    int timeout_ = 0;

    //* timer
    QBasicTimer timer_;

    //* activity
    QThread* activityThread_ = nullptr;

};

#endif
