#ifndef MessageEditorWidget_h
#define MessageEditorWidget_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "LineEditor.h"

#if USE_ASPELL
#include "DictionaryMenu.h"
#include "SpellParser.h"
#endif

#include <QContextMenuEvent>
#include <QTextCharFormat>

class MessageEditorWidget: public LineEditor
{

    Q_OBJECT

    public:

    //* constructor
    MessageEditorWidget( QWidget* = nullptr );


    //*@name modifiers
    //@{

    //* install actions in context menu
    virtual void installContextMenuActions( BaseContextMenu* );

    //@}

    //*@name actions
    //@{

    #if USE_ASPELL

    //* spellcheck dictionary selection
    QAction& dictionaryMenuAction( void ) const
    { return *dictionaryMenuAction_; }

    //* autospell
    QAction& autoSpellAction( void ) const
    { return *autoSpellAction_; }

    #endif

    //* remove message action
    QAction& removeMessageAction( void ) const
    { return *removeMessageAction_; }

    //* cancel message edition
    QAction& cancelMessageEditionAction( void ) const
    { return *cancelMessageEditionAction_; }

    //@}

    protected Q_SLOTS:

    //* toggle auto spell
    void _toggleAutoSpell( bool );

    //* run spell checking
    void _spellcheck( void );

    protected:

    //* context menu event
    virtual void contextMenuEvent( QContextMenuEvent* );

    //* raise autospell context menu
    /*! returns true if autospell context menu is used */
    virtual bool _autoSpellContextEvent( QContextMenuEvent* );

    private Q_SLOTS:

    //* misspelled words
    void _ignoreMisspelledWord( QString );

    //* replace misspelled words
    void _replaceMisspelledSelection( QString );

    //* change spellcheck dictionary
    void _selectDictionary( const QString& );

    //* update configuration
    void _updateSpellCheckConfiguration( void );

    private:

    //* install actions
    void _installActions( void );

    //*@name actions
    //@{
    #if USE_ASPELL

    //* toggle spellcheck action
    QAction* autoSpellAction_ = nullptr;

    //* spellcheck dictionary selection menu
    QAction* dictionaryMenuAction_ = nullptr;

    #endif

    //* remove message action
    QAction* removeMessageAction_ = nullptr;

    //* edit message action
    QAction* cancelMessageEditionAction_ = nullptr;

    //@}

    #if USE_ASPELL

    //* spellcheck dictionary selection menu
    SpellCheck::DictionaryMenu* dictionaryMenu_;

    //* spell check parser
    SpellCheck::SpellParser spellParser_;

    //* misspelled words
    SpellCheck::Word::Set misspelledWords_;

    //* spell check highlight format
    QTextCharFormat spellcheckFormat_;

    #endif

};

#endif
