#ifndef SoundNotifications_h
#define SoundNotifications_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"

#include <QObject>
#include <QStringList>

class SoundNotificationsP;

class SoundNotifications: public QObject, public Counter
{

    Q_OBJECT

    public:

    //* notification type
    enum Type
    {
        ContactOnline,
        ContactOffline,
        NewMessage,
        FileTransferRequest,
        None
    };

    //* constructor
    SoundNotifications( QObject* = nullptr );

    //* destructor
    virtual ~SoundNotifications( void );

    //*@name accessors
    //@{

    //* true if supported
    bool isSupported( void ) const;

    //@}

    //*@name modifiers
    //@{

    //* set mask
    void setNotificationMask( int value )
    { mask_ = value; }

    //* play
    void play( Type );

    //@}

    protected Q_SLOTS:

    //* thread finished
    void _threadFinished( void );

    private:

    //* list of notifications to be played
    QStringList filenames_;

    //* sound notification mask
    int mask_ = 0xf;

    //* private
    SoundNotificationsP* d = nullptr;

};

#endif
