/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "SoundNotificationsOptionWidget.h"

#include<QLayout>

//_________________________________________________________________
SoundNotificationsOptionWidget::SoundNotificationsOptionWidget( QWidget* parent, const QString& optionName ):
    QWidget( parent ),
    OptionWidget( optionName, this )
{
    QVBoxLayout* vLayout = new QVBoxLayout();
    vLayout->setMargin(0);
    setLayout( vLayout );

    QStringList names = QStringList()
        << tr( "Contact came online" )
        << tr( "Contact went offline" )
        << tr( "Chat message received" )
        << tr( "File transfer request" );

    for( int i = 0; i < SoundNotifications::None; ++i )
    {
        QCheckBox* checkbox = new QCheckBox( names[i], this );
        vLayout->addWidget( checkbox );
        checkBoxes_.insert( (SoundNotifications::Type) i, checkbox );
    }
}

//_________________________________________________________________
void SoundNotificationsOptionWidget::read( const Options& options )
{
    int mask = options.get<int>( optionName() );
    for( auto&& iter = checkBoxes_.begin(); iter != checkBoxes_.end(); ++iter )
    { iter.value()->setChecked( mask & (1<<iter.key()) ); }

    if( !_connected() )
    {
        for( auto&& iter = checkBoxes_.begin(); iter != checkBoxes_.end(); ++iter )
        { connect( iter.value(), SIGNAL(toggled(bool)), SIGNAL(modified()) ); }
        _setConnected();
    }

}


//_________________________________________________________________
void SoundNotificationsOptionWidget::write( Options& options ) const
{
    int mask = 0;
    for( auto&& iter = checkBoxes_.begin(); iter != checkBoxes_.end(); ++iter )
    { if( iter.value()->isChecked() ) mask |= (1<<iter.key()); }

    options.set<int>( optionName(), mask );
}
