/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "SshConnectionWidget.h"
#include "Debug.h"
#include "LineEditor.h"


#include <QLabel>
#include <QLayout>


namespace Ssh
{

    //___________________________________________________________
    ConnectionWidget::ConnectionWidget( QWidget* parent ):
        QWidget(parent)
    {

        Debug::Throw( "ConnectionWidget::ConnectionWidget.\n" );

        // grid layout
        setLayout( layout_ = new GridLayout() );
        layout_->setMargin(0);
        layout_->setSpacing(5);
        layout_->setMaxCount(4);
        layout_->setColumnAlignment(0, Qt::AlignRight|Qt::AlignVCenter );

        // name
        QLabel* label;
        layout_->addWidget( label = new QLabel( tr( "Host:" ), this ) );
        layout_->addWidget( hostEditor_ = new LineEditor( this ) );
        label->setBuddy( hostEditor_ );

        layout_->addWidget( label = new QLabel( tr( "Port:" ), this ) );
        layout_->addWidget( portSpinBox_ = new QSpinBox( this ) );
        portSpinBox_->setMinimum(0);
        portSpinBox_->setMaximum(10000);
        label->setBuddy( portSpinBox_ );

        layout_->addWidget( label = new QLabel( tr( "User:" ), this ) );
        layout_->addWidget( userEditor_ = new LineEditor( this ), 1, 1, 1, 3 );
        label->setBuddy( userEditor_ );

        layout_->addWidget( label = new QLabel( tr( "Password:" ), this ) );
        layout_->addWidget( passwordEditor_ = new LineEditor( this ), 2, 1, 1, 3 );
        label->setBuddy( passwordEditor_ );
        passwordEditor_->setEchoMode( QLineEdit::Password );

        layout_->addWidget( rememberPassword_ = new QCheckBox( tr( "Remember password" ), this ), 3, 1, 1, 3 );

    }

    //________________________________________
    void ConnectionWidget::setAttributes( const ConnectionAttributes& attributes )
    {
        Debug::Throw( "ConnectionWidget::setAttributes.\n" );

        // store connection name
        name_ = attributes.name();

        hostEditor_->setText( attributes.host() );
        portSpinBox_->setValue( attributes.port() );
        userEditor_->setText( attributes.userName() );
        rememberPassword_->setChecked( attributes.rememberPassword() );

        if( attributes.rememberPassword() )
        { passwordEditor_->setText( attributes.password() ); }

    }

    //________________________________________
    void ConnectionWidget::hidePasswordEditor( void )
    {
        layout_->itemAtPosition( 2, 0 )->widget()->hide();
        layout_->itemAtPosition( 2, 1 )->widget()->hide();
    }

    //________________________________________
    void ConnectionWidget::hideSavePassword( void )
    { rememberPassword_->hide(); }

    //________________________________________
    ConnectionAttributes ConnectionWidget::attributes( void ) const
    {
        Debug::Throw( "ConnectionWidget::attributes.\n" );
        ConnectionAttributes out;
        out.setName( name_ );
        out.setHost( hostEditor_->text() );
        out.setPort( portSpinBox_->value() );
        out.setUserName( userEditor_->text() );
        out.setPassword( passwordEditor_->text() );
        out.setRememberPassword( rememberPassword_->isChecked() );
        return out;
    }

}
