#ifndef SshConnectionWidget_h
#define SshConnectionWidget_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "SshConnectionAttributes.h"
#include "GridLayout.h"

#include <QCheckBox>
#include <QPushButton>
#include <QSpinBox>

class LineEditor;

namespace Ssh
{

    //* handles ssh connection attributes
    class ConnectionWidget: public QWidget
    {

        Q_OBJECT

        public:

        //* constructor
        ConnectionWidget( QWidget* = nullptr );

        //*@name accessors
        //@{

        //* get connection attributes
        ConnectionAttributes attributes( void ) const;

        //* name
        QString name( void ) const
        { return name_; }

        //@}

        //*@name modifiers
        //@{

        //* set connection attributes
        void setAttributes( const ConnectionAttributes& );

        //* set connection name
        void setName( const QString& name )
        { name_ = name; }

        //* hide password editor
        void hidePasswordEditor( void );

        //* hide save password
        void hideSavePassword( void );

        //@}

        private:

        //* layout
        GridLayout* layout_ = nullptr;

        //* host
        LineEditor* hostEditor_ = nullptr;

        //* port
        QSpinBox* portSpinBox_ = nullptr;

        //* user
        LineEditor* userEditor_ = nullptr;

        //* user
        LineEditor* passwordEditor_ = nullptr;

        //* auto connect
        QCheckBox* rememberPassword_ = nullptr;

        //* connection name
        QString name_;

    };

}

#endif
