#ifndef SshInterface_h
#define SshInterface_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CommandLineParser.h"
#include "SshConnection.h"

#include <QObject>

namespace Ssh
{
    class Interface: public QObject, public Counter
    {

        //* Qt meta object declaration
        Q_OBJECT

        public:

        //* constructor
        Interface( QObject*, const CommandLineParser& = CommandLineParser() );

        //*@name accessors
        //@{

        //* ssh connection
        Connection& connection( void ) const
        { return *connection_; }

        //* true if connected
        bool isConnected( void ) const
        { return connection_->isConnected(); }

        //@}

        using QObject::connect;

        Q_SIGNALS:

        //* emitted when error is recieved
        void error( QString );

        //* emitted when connected
        void connected( void );

        public Q_SLOTS:

        //* connect
        virtual void connect( void );

        //* disconnect
        virtual void disconnect( void );

        private Q_SLOTS:

        //* update connection attributes when connected
        void _updateAttributes( void );

        //* notify login failed
        void _notifyLoginFailed( void );

        //* update configuration
        void _updateConfiguration( void );

        private:

        // command line parser (passed at initialization)
        CommandLineParser parser_;

        //* connection attributes
        ConnectionAttributes attributes_;

        //* connection
        Connection* connection_ = nullptr;

    };

}

#endif
