#ifndef SynchronizationApplication_h
#define SynchronizationApplication_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseApplication.h"
#include "Config.h"

#include "PixmapEngine.h"

#include <QSystemTrayIcon>

namespace Ssh
{
    class SynchronizationDialog;

    //* Main Window singleton object
    class SynchronizationApplication: public BaseApplication, public Counter
    {

        //* Qt meta object declaration
        Q_OBJECT

            public:

            //* constructor
            SynchronizationApplication( CommandLineArguments );

        //*@name modifier
        //@{

        //* create all widgets
        virtual bool realizeWidget( void );

        //@}

        //*@name accessors
        //@{

        //* synchronization dialog
        Ssh::SynchronizationDialog& synchronizationDialog( void ) const
        { return *synchronizationDialog_; }

        //* usage
        void usage( void ) const;

        //* application name
        virtual QString applicationName( void ) const
        { return "Homechat synchronize"; }

        //* application icon
        virtual QIcon applicationIcon( void ) const
        {
            QIcon icon;
            icon.addPixmap( PixmapEngine::get( ":/homechat.png" ) );
            icon.addPixmap( PixmapEngine::get( ":/homechat-large.png" ) );
            return icon;
        }

        // application version
        virtual QString applicationVersion( void ) const
        { return VERSION; }

        //@}

        protected Q_SLOTS:

        //* configuration
        virtual void _configuration( void )
        {}

        private:

        //* communication interface
        Ssh::SynchronizationDialog* synchronizationDialog_ = nullptr;

    };

}

#endif
