#ifndef SshSynchronizationDialog_h
#define SshSynchronizationDialog_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "SshConnectionAttributes.h"
#include "SshConnection.h"

#include "BaseDialog.h"
#include "ChatMessageSet.h"
#include "File.h"

#include <QCloseEvent>
#include <QLabel>
#include <QProgressBar>
#include <QPushButton>
#include <QWidget>


class LogWidget;

namespace Ssh
{

    class SynchronizationDialog: public BaseDialog, public Counter
    {

        Q_OBJECT

        public:

        //* constructor
        SynchronizationDialog( QWidget* );

        //*@name modifiers
        //@{

        //* add connection
        void addConnection( ConnectionAttributes, File );

        //* read connection attributes
        void readConnectionAttributes( void );

        //* write connection attributes
        void writeConnectionAttributes( void );

        //@}

        protected:

        //* close event
        virtual void closeEvent( QCloseEvent* );

        protected Q_SLOTS:

        //* add an empty connection
        void _addConnection( void );

        //* synchronize
        bool _synchronize( void );

        //* abort
        void _abort( void );

        //* append transfer progress to log
        void _append( QString );

        //* append transfer progress to log
        void _appendTransfer( qint64, qint64 );

        //* update sync button
        void _connectionWidgetDestroyed( void );

        //* update sync button
        void _updateSynchronizationButton( void );

        private:

        //* copy remote file to local
        bool _copyToLocal( Connection&, File remote, File localPath );

        //* copy local file to remote
        bool _copyToRemote( Connection&, File local, File remotePath );

        //* copy home chat message from remote server
        using ChatMessagePair = std::pair<ChatMessageSet,bool>;
        ChatMessagePair _copyFromRemote( ConnectionAttributes, File localPath, File remotePath );

        //* copy home chat message from remote server
        bool _copyToRemote( ConnectionAttributes, File localPath, File remotePath );

        //* connection layout
        QLayout* layout_ = nullptr;

        //* text editor (for logging)
        LogWidget* logWidget_ = nullptr;

        //* progress bar
        QProgressBar* progressBar_ = nullptr;

        //* synchronize button
        QPushButton* synchronizeButton_ = nullptr;

        //* abort button
        QPushButton* abortButton_ = nullptr;

        //* close button
        QPushButton* closeButton_ = nullptr;

        //* true when synchronization is aborted
        bool aborted_ = false;

    };

}

#endif
