#ifndef SyntaxHighlighter_h
#define SyntaxHighlighter_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"

#include <QColor>
#include <QMap>
#include <QRegExp>
#include <QString>
#include <QSyntaxHighlighter>
#include <QTextDocument>
#include <QVector>

class SyntaxHighlighter: public QSyntaxHighlighter, public Counter
{

    Q_OBJECT

    public:

    //* constructor from document
    SyntaxHighlighter( QTextDocument* );

    //* regular expression
    const QRegExp& regExp( void ) const
    { return regexp_; }

    //* enable state
    void setEnabled( bool value )
    { enabled_ = value; }

    protected:

    //* highlight
    virtual void highlightBlock( const QString& );

    private Q_SLOTS:

    //* update configuration
    void _updateConfiguration( void );

    private:

    //* enabled state
    bool enabled_ = true;

    //* header regexp
    QRegExp regexp_;

    //* date color
    QColor timeColor_;

    //* color list
    QVector<QColor> colors_;

    //* color index
    int colorIndex_ = 0;

    //* map users to colors
    using UserMap = QMap<QString, QColor>;
    UserMap userMap_;

};

#endif
