#ifndef SystemTrayIcon_h
#define SystemTrayIcon_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "ClientInterface.h"
#include "ConnectionId.h"
#include "Debug.h"

#include <QSystemTrayIcon>
#include <QIcon>
#include <QMap>

class SystemTrayMenu;
class SystemTrayToolTipWidget;

//* application system tray icon
class SystemTrayIcon: public QSystemTrayIcon, public Counter
{

    Q_OBJECT;

    public:

    //* constructor
    SystemTrayIcon( QObject* = nullptr );

    //* destructor
    virtual ~SystemTrayIcon( void );

    //*@name modifiers
    //@{

    //* set connection id
    void setConnectionId( ConnectionId );

    //* set contacts
    void setContacts( const ConnectionId::List& );

    //@}

    public Q_SLOTS:

    //* update icon based on whether there are pending messages
    void updatePendingMessages( bool );

    //* update contact
    void updateContact( ConnectionId, ConnectionId);

    //* remove a contact from contact list
    void removeContact( ConnectionId );

    protected:

    //* generic event handler
    virtual bool event( QEvent* );

    protected Q_SLOTS:

    void _activated( QSystemTrayIcon::ActivationReason );

    //* update tooltip
    void _updateToolTip( void );

    private:

    //* show context menu
    void _showContextMenu( void ) const;

    //* connected icon
    QIcon connectedIcon_;

    //* disconnected icon
    QIcon disconnectedIcon_;

    //* pending messages icon
    QIcon pendingMessagesIcon_;

    //* tooltip
    SystemTrayToolTipWidget* toolTipWidget_ = nullptr;

    //* menu
    SystemTrayMenu* contextMenu_ = nullptr;

    //* id
    ConnectionId connectionId_;

    //* set of connected clients
    ConnectionId::List contacts_;

    //* pending messages count
    int messageCount_ = 0;

};

#endif
