/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Debug.h"
#include "DefaultOptions.h"
#include "Options.h"
#include "ChatMessageMigration.h"
#include "ClientApplication.h"
#include "ResourceMigration.h"
#include "Singleton.h"
#include "SystemOptions.h"
#include "Util.h"

#include <QApplication>

#if defined(QT_USE_STATIC_PLUGINS)
#include <QtPlugin>
Q_IMPORT_PLUGIN(qsvg)
#endif

//__________________________________________
//* main function
int main (int argc, char *argv[])
{

    // options
    installDefaultOptions();
    installSystemOptions();

    // resource file
    XmlOptions::get().set( "OLD_RC_FILE", Option( File(".homechatrc").addPath(Util::home()), Option::None ), true );
    XmlOptions::get().set( "RC_FILE", Option( File("homechatrc").addPath(Util::config()), Option::None ), true );

    // migrate old rc files
    File oldRCFile( XmlOptions::get().raw( "OLD_RC_FILE" ) );
    File rcFile( XmlOptions::get().raw( "RC_FILE" ) );
    ResourceMigration( oldRCFile ).migrate( rcFile );

    XmlOptions::setFile( rcFile );
    XmlOptions::read();

    // migrate hitory
    File oldHistoryFile( XmlOptions::get().raw( "OLD_HISTORY_FILE" ) );
    File historyFile( XmlOptions::get().raw( "HISTORY_FILE" ) );
    ChatMessageMigration( oldHistoryFile ).migrate( historyFile );

    // debug level
    Debug::setLevel( XmlOptions::get().get<int>("DEBUG_LEVEL") );
    if( Debug::level() ) Debug::Throw() << XmlOptions::get() << endl;

    if( !XmlOptions::get().contains( "USERNAME" ) )
    { XmlOptions::get().setRaw( "USERNAME", Util::user(), true ); }

    // resources
    Q_INIT_RESOURCE( basePixmaps );
    Q_INIT_RESOURCE( pixmaps );
    Q_INIT_RESOURCE( sounds );

    // QApplication
    QApplication application( argc, argv );

    // singleton application is deleted before QApplication
    ClientApplication singleton( CommandLineArguments( argc, argv ) );
    Singleton::get().setApplication( &singleton );

    // initialize and run
    if( singleton.initApplicationManager() )
    { application.exec(); }

    return 0;

}
