/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "DefaultOptions.h"
#include "ResourceMigration.h"
#include "SystemOptions.h"

#include "Singleton.h"
#include "SshConnectionAttributes.h"
#include "SshSynchronizationApplication.h"
#include "SshSynchronizationDialog.h"

#include <QApplication>

//__________________________________________
//* main function
int main (int argc, char *argv[])
{

    // options
    installDefaultOptions();
    installSystemOptions();

    XmlOptions::get().set( "OLD_RC_FILE", Option( File(".homechat-synchronizerc").addPath(Util::home()), Option::None ), true );
    XmlOptions::get().set( "RC_FILE", Option( File("homechat-synchronizerc").addPath(Util::config()), Option::None ), true );

    // migrate old rc files
    File oldRCFile( XmlOptions::get().raw( "OLD_RC_FILE" ) );
    File rcFile( XmlOptions::get().raw( "RC_FILE" ) );
    ResourceMigration( oldRCFile ).migrate( rcFile );

    XmlOptions::setFile( rcFile );
    XmlOptions::read();

    // debug level
    Debug::setLevel( XmlOptions::get().get<int>("DEBUG_LEVEL") );
    if( Debug::level() ) Debug::Throw() << XmlOptions::get() << endl;

    // resources
    Q_INIT_RESOURCE( basePixmaps );
    Q_INIT_RESOURCE( pixmaps );

    // QApplication
    QApplication application( argc, argv );

    // singleton application is deleted before QApplication
    Ssh::SynchronizationApplication singleton( CommandLineArguments( argc, argv ) );
    Singleton::get().setApplication( &singleton );

    if( !singleton.initApplicationManager() ) return 0;

    singleton.realizeWidget();

    application.exec();
    return 0;

}

//_____________________________________________
void interrupt( int sig )
{
    Debug::Throw() << "main-synchronize::interrupt - Recieved signal " << sig << endl;
    exit(0);
}
